@@ -5,9 +5,9 @@ import math
 import datetime as dt
 from kucoincli.client import Client
 
-####################################################################################################################
-# Data pipeline connecting kucoin historic OHLCV data (acquired via API) to SQL schema through SQLAlchemy engine.
-####################################################################################################################
+###################################################################################################################
+# Data pipeline connecting kucoin historic OHLCV data (acquired via API) to SQL schema through SQLAlchemy engine. #
+###################################################################################################################
 
 # Features I still want to add...
 # Progress bar does not reach 100% if end of data is found (needs fixed)
@@ -16,7 +16,7 @@ from kucoincli.client import Client
 def pipeline(
     tickers: list, schema: str, engine, interval: int, from_date, to_date=None, 
     loop_range:int=None, loop_increment:int=1500, chunk_size:int=500, 
-    if_exists:str="append", error_msg:bool=False, progress_bar:bool=True,
+    if_exists:str="append", msg:bool=False, progress_bar:bool=True,
 ) -> None:
     """
     Data acquisition pipeline from KuCoin OHLCV API call ----> SQL database.
@@ -49,7 +49,7 @@ def pipeline(
             fail: Raise a ValueError.
             replace: Drop the table before inserting new values.
             append: Insert new values to the existing table.
-    :param error_msg: bool Print out any error messages recieved; Default=False
+    :param msg: bool Print out any error messages recieved; Default=False
     :param progress_bar: bool Display progress bar; Default=True
 
     :return: None
@@ -101,7 +101,7 @@ def pipeline(
             now = from_date - dt.timedelta(minutes=(period_start * increment_dict[interval]))
             begin = from_date - dt.timedelta(minutes=(period_stop * increment_dict[interval]))
             df = client.get_kline_history(
-                ticker, begin, now, interval, error_msg=error_msg
+                ticker, begin, now, interval, msg=msg
             )
             if df.empty: # If the server gives us no data, break to avoid error
                 break
@@ -144,4 +144,3 @@ def pipeline(
                     bar.next()  # Moves progress bar along
         if progress_bar:
             bar.finish()
-
